# ssb-datadoc-model

Data Model for use in Statistics Norway's Metadata system

## Purpose

This package contains pydantic models defining the fields and data types used in Statistics Norway's metadata system. The purpose of these models is to:

- Enable validation of user data
- Enable serialization and deserialization of metadata files
- Support versioning of the metadata format
- Enforce consistency across multiple tools

## Single Source of Truth

Fields and data types defined in models in this package are specified on internal Statistics Norway wiki pages:

- <https://statistics-norway.atlassian.net/l/cp/kQ9rpshS>
